package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````4"(```````!``````````#BQ````
M`````````$``.``-`$``&0`8``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````.`9````````X!D`````````
M$`````````$````%`````"``````````(``````````@````````H3L`````
M``"A.P`````````0`````````0````0`````8`````````!@`````````&``
M``````"81P```````)A'`````````!`````````!````!@````"L````````
M`+P`````````O````````"@$````````4`0`````````$`````````(````&
M````$*P````````0O````````!"\````````T`$```````#0`0````````@`
M````````!`````0````X`P```````#@#````````.`,```````!0````````
M`%``````````"``````````$````!````(@#````````B`,```````"(`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````4`````````!0``````````@`````````4.5T9`0`
M``"@H````````*"@````````H*````````#D`````````.0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$`````*P`````````O`````````"\````
M``````0`````````!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````0`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````!``'`!`````D``````````@`!P`0````!````
M``````0````4`````P```$=.50"^S%W?]$%;_?>^TI<`%PY6V:EA%@0````0
M`````0```$=.50``````!`````0``````````````"L```!#````!`````@`
M```@$!``!4`$A"@"``2`A@"$@@D```D@!`B(@!!!N@`""$,`````````````
M`$0``````````````$4``````````````$8`````````1P````````!)````
M``````````!*````2P````````!,````30```$\`````````4````%$```!2
M``````````````````````````````!3````5````%4```!6````5P``````
M````````60````````!:``````````````")!W#3:QJ>4*/@^TGC1\8!9J_,
M9D-%U>R[XY)\LP&+;V_%WQ\5C"7,+L6;MFL)0]8A_^0.^Z%L8,/E/RP-.I<+
MS]Y'+=EQ6!Q_J9R;X:<""D+ZUX=K?YI\,V+;[=1DU'RM2^/`````````````
M````````````````````C0(``!(`````````````````````````]`$``!(`
M````````````````````````C````!$`````````````````````````=`(`
M`!(`````````````````````````2P$``!(`````````````````````````
MSP$``!(`````````````````````````,`(``!(`````````````````````
M`````0```"``````````````````````````R`(``!(`````````````````
M````````9P```!(`````````````````````````LP```!(`````````````
M````````````E````!(`````````````````````````;0(``!(`````````
M````````````````OP(``!(`````````````````````````Y`$``!(`````
M````````````````````WP```!(`````````````````````````[P```!(`
M````````````````````````/0$``!(`````````````````````````<0$`
M`!(`````````````````````````B@```!$`````````````````````````
M8@,``!(`````````````````````````$````"``````````````````````
M````I0(``!(`````````````````````````D@(``!(`````````````````
M````````R@```!(`````````````````````````+````"``````````````
M````````````G0```!(`````````````````````````N````!(`````````
M````````````````EP(``!(`````````````````````````6````"(`````
M````````````````````]0```!8`````````````````````````"`$``!(`
M````````````````````````0P(``!(`````````````````````````(P$`
M`!(`````````````````````````L`(``!(`````````````````````````
MFP$``!(`````````````````````````W0$``!(`````````````````````
M````J@$``!(`````````````````````````4@$``!(`````````````````
M````````-`$``!(`````````````````````````80$``!(`````````````
M````````````?P$``!(`````````````````````````?P(``!(`````````
M````````````````MP$``!(`````````````````````````A@$``!(`````
M````````````````````%0(``!(`````````````````````````>0```!(`
M````````````````````````E`$``!(`````````````````````````C0$`
M`!(`````````````````````````G````!(`````````````````````````
MHP$``!(```````````````````````````(``!(`````````````````````
M````80(``!(`````````````````````````JP```!(`````````````````
M````````Y@```!(`````````````````````````T0```!(`````````````
M````````````R`$``!$`````````````````````````5`(``!$`````````
M````````````````I````!(`````````````````````````:0$``!(`````
M````````````````````&`$``!(`````````````````````````(0(``!(`
M````````````````````````1@```!(`````````````````````````>`$`
M`!(`````````````````````````P````!(`````````````````````````
ML0$``!(`````````````````````````\P,``!$`%0`@P`````````@`````
M````1@,``!(`#``@60```````%4"````````_0,``!(`#```1@````````4%
M````````\P(``!(`#`"`1````````"@`````````.@,``!(`#`"P1```````
M`$(!````````S0,``!``%0`HP```````````````````NP,``!``%@!0P```
M````````````````%@,``!(`#``02P```````&H`````````:P,``!(`#`!`
M5@```````-T`````````L@,``!(`#``@5P```````$H`````````X@(``!(`
M#`!`0@````````H`````````A@,``!``%0``P```````````````````Y@,`
M`!(`#`!00@```````"4"````````U`,``!(`#`"P2P```````!`!````````
MG@,``!(`#``P00```````"H`````````B`,``"``%0``P```````````````
M````P`,``!(`#`#`3````````!,'````````I@,``!``%@`HP```````````
M````````4`,``!(`#`"`2P```````",`````````)`,``!(`#`!@00``````
M`-D`````````DP,``!(`#`!P5P```````*<!````````4P```!(`#``@(```
M`````"("````````C`,``!(`#`!0(@```````"8```````````,``!(`#`#@
M4P```````%,"````````=P,``!$`#@``8`````````0``````````%]?9VUO
M;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%]?;&EB8U]S=&%R=%]M86EN`%]?8WAA7V9I
M;F%L:7IE`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V9A:6P`7U]E
M;G9I<F]N`'-T<FYC;7``;'-T870V-`!A8V-E<W,`;'-E96LV-`!R96%D`&]P
M96YD:7(`<F5A9&1I<C8T`'-T<FQE;@!?7W-P<FEN=&9?8VAK`'5N;&EN:P!C
M;&]S961I<@!R;61I<@!03%]C=7)R96YT7V-O;G1E>'0`8F]O=%]$>6YA3&]A
M9&5R`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!R96%D;&EN:P!097)L
M7W-V7W-E='!V`&UE;6-H<@!097)L7W-V7W-E='!V;@!M96UM;W9E`')E86QL
M;V,`9V5T<&ED`&UE;6-P>0!S=')C:'(`<W1R9'5P`'-T<G1O:P!S=')C;7``
M<W1R<F-H<@!G971U:60`<W1R<W1R`&UK9&ER`%]?97)R;F]?;&]C871I;VX`
M<W1D97)R`%]?9G!R:6YT9E]C:&L`;W!E;C8T`%!E<FQ?9W9?9F5T8VAP=@!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?
M;&]C:P!03%]D;U]U;F1U;7``4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?<&%R
M<V4`<&5R;%]D97-T<G5C=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L
M7V%L;&]C`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?<G5N`&5X:70`;&EB<&5R;"YS
M;P!L:6)C+G-O+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?
M26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?
M97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?
M9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A
M=&%?<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I
M;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T
M:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R
M+C$T`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?,BXS
M+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR+C4`+W5S<B]L:6(O<&5R;#4O-2XS
M-B]C;W)E7W!E<FPO0T]210````$``0`"``$``@`#``$``0`"``0``@`"``(`
M`0`!``(``@`!``(``@`"``$``0`"``(``0`%``(``0`"``$``0`!``$``0`"
M``(``@`!``(``@`"``$``@`"``$`!@`"``(`!0`"``$``0`"``(``P`"``$`
M`@`"``$``0`'``@``@`"``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$```````$`!P#8`@``$`````````"4D98&
M```(``H$```0````M)&6!@``!P`5!```$````!1I:0T```8`(`0``!````"S
MD98&```%`"H$```0````<AEI"0``!``U!```$````'09:0D```,`000``!``
M``!U&FD)```"`$T$`````````+P````````(`````````$`C````````"+P`
M```````(`````````/`B````````",`````````(``````````C`````````
M(,`````````(`````````-AB````````^+T````````&`````0``````````
M`````+X````````&`````@``````````````"+X````````&`````P``````
M````````$+X````````&````!```````````````&+X````````&````!0``
M````````````(+X````````&````!@``````````````*+X````````&````
M!P``````````````,+X````````&````"```````````````.+X````````&
M````"0``````````````0+X````````&````"@``````````````2+X`````
M```&````"P``````````````4+X````````&````#```````````````6+X`
M```````&````#0``````````````8+X````````&````#@``````````````
M:+X````````&````#P``````````````<+X````````&````$```````````
M````>+X````````&````$0``````````````@+X````````&````$@``````
M````````B+X````````&````$P``````````````D+X````````&````%0``
M````````````F+X````````&````%@``````````````H+X````````&````
M%P``````````````J+X````````&````&```````````````L+X````````&
M````&0``````````````N+X````````&````&@``````````````P+X`````
M```&````&P``````````````R+X````````&````'```````````````T+X`
M```````&````'0``````````````V+X````````&````'@``````````````
MX+X````````2````'P``````````````Z+X````````&````(```````````
M````\+X````````&````(0``````````````^+X````````&````(@``````
M`````````+\````````&````(P``````````````"+\````````&````)```
M````````````$+\````````&````)0``````````````&+\````````&````
M)@``````````````(+\````````&````)P``````````````*+\````````&
M````*```````````````,+\````````&````*0``````````````.+\`````
M```&````*@``````````````0+\````````&````*P``````````````2+\`
M```````&````+```````````````4+\````````&````+0``````````````
M6+\````````&````+@``````````````8+\````````&````+P``````````
M````:+\````````&````,```````````````<+\````````&````,0``````
M````````>+\````````&````,@``````````````@+\````````&````,P``
M````````````B+\````````&````-```````````````D+\````````&````
M-0``````````````F+\````````&````-@``````````````H+\````````&
M````-P``````````````J+\````````&````.```````````````L+\`````
M```&````.0``````````````N+\````````&````.@``````````````P+\`
M```````&````.P``````````````R+\````````&````/```````````````
MT+\````````&````/0``````````````V+\````````&````/@``````````
M````X+\````````&````/P``````````````Z+\````````&````0```````
M````````\+\````````&````00``````````````^+\````````&````0@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!2&>``!(A<!T`O_02(/$",,``````/,/'OI54TB#[#B)
M?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E*````$B)1"0H,<#_
M%7N?``!(BS7$G0``2(L]A9X``$B)\F?H##L``$B+!3V?``"`.``/A"(!``!(
MBP55G@``9$B+`("(*@0```.+1"0<C7@$C5@#2&/_2,'G`_\5XYX``$B+3"00
M1(M$)!Q(B<9(B06'GP``2(L!2(D&2(T%]4```$B)1@A(C05'GP``2(L`2(E&
M$$B-!=]```!(B48808/X`0^.,@$``$B#P0A!@\`#N`0```!F#Q]$``!(BSE(
M8]"#P`%(@\$(2(D\UD0YP'7J2)A(B?&)VDB+/0R?``!(QP3&`````$4QP$B-
M-6(<``#_%<R<``")PX7`#X2*````2(UL)"1(BSW>G@``_Q7@G0``,<!(B>Y(
MC3TW/P``Z$\8``!(A<!T=DB+/;N>``#_%76<``#_%4>=``!(BT0D*&1(*P0E
M*`````^%GP```$B#Q#B)V%M=P_\5])P``$B)!86>``!(B<=(A<!T=O\5/YT`
M`$B+!1B=``!D2(L0QH+7"0```.FS_O__2(L]69X``/\5>YP``(G#Z6+___](
MBSU-G@``2(7_=`MGZ$(T``#I<____TB-/4X^``!(B>[HKA<``$B)!2>>``!(
MB<=(A<`/A%'____KT;@$````Z>W^__^_`0```/\5_)L``/\5'IT``&8N#Q^$
M```````/'T``\P\>^C'M28G17DB)XDB#Y/!05$4QP#')2(T]L?W___\5:YT`
M`/1F+@\?A```````2(T]H9T``$B-!9J=``!(.?AT%4B+!?Z;``!(A<!T"?_@
M#Q^``````,,/'X``````2(T]<9T``$B--6J=``!(*?Y(B?!(P>X_2,'X`T@!
MQDC1_G042(L%W9L``$B%P'0(_^!F#Q]$``###Q^``````/,/'OJ`/2V=````
M=3-52(,]TIL```!(B>5T#4B+/?:<``#_%<";``#H8____\8%!)T```%=PV8N
M#Q^$``````##9F8N#Q^$```````/'T``\P\>^NEG____#Q^``````$%72(G^
M3(U'.$%6055!5%532('LF`(``&1(BP0E*````$B)A"2(`@``,<!(B>),C8PD
M@````$B)UP\?@`````!!BP!-BQ!(@\<028/`"`_(B<!,B=%(B4?P3(G02,'I
M($C!Z"A)P>HX)0#_``!,"=!)B<I(P>$(2<'B&('A``#_`$6)TDP)T$@)R$B)
M1_A,.<]UK68/;TPD$&8/;UPD($B-1"1H2('":`(``&8/;U0D,&8/;RU7?```
M#Q^``````/,/;P!F#V_B9@]O4-A(@\`09@_O2(AF#^_"9@_OP68/;\AF#W/0
M'V8/<_$!9@_KP68/;\MF#V_<9@_;Q0\I0`A(.=!UNTR+#DR+7A!(BWX@2(M>
M&$R)R$R)RDB+;@A(BTPD"$C!ZAM(P>`%2`G0`P0D2(V,"YEY@EJ-E#B9>8):
M3(G82#'82"'H2#'8C3P"2(GJ2(GH2,'H`DC!XAY)B?I("<),B=A)P>H;08G0
M3#'`3"'(3#'82`'(2(GY2,'A!4P)T4R+5"001(TD"$R)R$R)R4C!Z0)(P>`>
M3XV4$YEY@EI-B>5("<A)P>T;2#'"B<%((?I,,<),`=)-B>))P>(%30GJ3(ML
M)!A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ38G52#'0B==,(>!)P>T;
M2#'(3`'`38G02<'@!4T)Z$R+;"0@00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"
M6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%3`GI3(ML)"@!T4R)
MTDG!Z@)(P>(>B<E*C;POF7F"6DP)TDF)S4@QT$G![1M!B=),(<!,,>!(`?A(
MB<](P><%3`GO3(ML)#`!QTR)P$G!Z`)(P>`>B?]/C:0LF7F"6DP)P$F)_4@Q
MPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL3(ML)#A!`=1(B<I(P>D"2,'B
M'D6)Y$^-E"J9>8):2`G*38GE2#'02<'M&XG12"'X3#'`3`'038GB2<'B!4T)
MZDR+;"1`00'"2(GX2,'O`DC!X!Y%B=)/C80HF7F"6D@)^$V)U4@QPDG![1N)
MQTPAXD@QRDP!PDV)T$G!X`5-">A,BVPD2$$!T$R)XDG![`)(P>(>18G`2HV,
M*9EY@EI,">)-B<5(,=!)P>T;08G43"'02#'X2`'(3(G!2,'A!4P)Z4R+;"10
M`<%,B=!)P>H"2,'@'HG)2HV\+YEY@EI,"=!)B<U(,<))P>T;08G"3"'"3#'B
M2`'Z2(G/2,'G!4P)[TR+;"18`==,B<))P>@"2,'B'HG_3XVD+)EY@EI,"<))
MB?U(,=!)P>T;08G02"'(3#'03`'@28G\2<'D!4T)[$R+;"1@00'$2(G(2,'@
M'DC!Z0)%B>1/C90JF7F"6D@)R$V)Y4@QPDG![1N)P4@A^DPQPDP!TDV)XDG!
MX@5-">I,BVPD:$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=!)
MP>T;B==,(>!(,<A,`<!-B=!)P>`%30GH3(ML)'!!`<!,B>!)P>P"2,'@'D6)
MP$J-C"F9>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,
MBVPD>`'13(G22,'B'DG!Z@*)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPA
MP$PQX$@!^$B)STC!YP5,">],BZPD@`````''3(G`2<'H`DC!X!Z)_T^-I"R9
M>8):3`G`28G]2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q&C2PB2(G*
M2,'I`DR+I"2(````2,'B'D@)RD^-E"*9>8):38GL2#'02<'L&XG12"'X3#'`
M3`'038GJ2<'B!4T)XDR+I"20````00'"2(GX2,'@'DC![P)%B=)/C80@F7F"
M6D@)^$V)U$@QPDG![!N)QTPAZD@QRDP!PDV)T$G!X`5-">!%B<!,`<)-B>A)
MP>T"2<'@'D&)U$T)Z$R+K"28````3#'`3"'02HV,*9EY@EI-B>5(,?A)P>T;
M2`'(3(GA2,'A!4P)Z8G)2`'(3(G12<'J`DC!X1Y!B<5,"=%-B<)%B<!),<I$
M,=),BY0DH````$J-O!>AZ]EN38GJ2`'73(GJ2<'J&TC!X@5,"=*)TD@!UTR)
MXDC!XAY)P>P"08GZ3`.$)*@```!,">))B<R)R4@#C"2P````23'41#'@38VD
M`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$3(GH2<'M`DC!X!Y%B>!,">A)
MB=6)TD@#E"2X````23'%1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)
M20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ
M2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(2`.$),````")
MR4DQT$@#C"3(````13'H3HVL`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'%
M2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"30````2#''1#'G3(VD.:'KV6Y,
MB<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#
MA"38````23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'53(G"
M2<'H`DC!XAY%B>I,"<))B<B)R4DQT$@#C"3@````13'@3HVD`*'KV6Y,B=!-
MB=!)P>@;2,'@!4P)P(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"3H
M````2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J
M`DC!X1Y$B>],"=%)B<*)P$@#A"3P````23'*13'B3HVD$J'KV6Y(B?I)B?I)
MP>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-
MK`"AZ]EN3(G038G02,'@!4G!Z!M(`XPD^````$P)P(G`20'%2(GX2,'O`DC!
MX!Y%B>A("?A(B=>)TD@#E"0``0``2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;
M2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#A"0(`0``23'*
M13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'53(G"2<'H`DC!XAY%
MB>I,"<))B<B)R4DQT$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!X`5,"<!(`XPD
M$`$``(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"08`0``2#''1#'O
M3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],
M"=%)B<*)P$@#A"0@`0``23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)
MTHG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G0
M38G02<'H&TC!X`5,"<")P$D!Q4B)^$C!X!Y(P>\"18GH2`.,)"@!``!("?A(
MB=>)TD@#E"0P`0``2#''1#'G38G$2(V,.:'KV6Y,B<=)P>P;2,'G!4P)YTV)
MU$G!Z@))P>0>B?]-"=1)B<)(`?F)P$TQXHG/2`.$)#@!``!%,>I)B?U.C902
MH>O9;DB)^DG![1M(P>(%3`GJ00'23(G"2<'H`DC!XAY%B=),"<)-B>!%B>1)
M,=!)B=9!B=5$,<%-B=!(C8P(H>O9;DR)T$G!Z!M(P>`%3`G`1(T$`4B)^4C!
M[P*XW+P;CTC!X1Y("?E)"<Z)ST@A^DTAUDD)UDB+E"1``0``2`'"3`'B38G$
M3`'R38G&2<'D!4G![AM-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)
MTDDA_DPAP4P)\4R+M"1(`0``20'&30'U38GF3`'I38GE2<'N&TG!Y05-"?5)
MB=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+M"10`0``
M20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>B?],">)(
M"=%)B=9!B=1-(<9,(>E,"?%,B[0D6`$``$D!QDT!\DF)_DP!T4F)^DG![AM)
MP>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),
MB[0D8`$``$D!QDT!\$V)UDP!PDV)T$G!X`5)P>X;30GP00'02(GZ2,'O`DC!
MXAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"1H`0``20'&30'T38G&3`'A
M38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4&)RDD)SDTA
MQDPATDP)\DR+M"1P`0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,
MB<)(P>(>2<'H`D6)[4P)PD@)T4F)UD&)T$TAUDPAX4P)\4R+M"1X`0``20'&
M3`'W38GN2`'Y3(GO2<'N&TC!YP5,"?=)B=8!STR)X4G![`)(P>$>B?],">%!
MB<Q)"<Y-(>Y,(>),"?),B[0D@`$``$D!QDT!\DF)_DP!TDF)^DG![AM)P>(%
M30GR00'23(GJ2<'M`DC!XAY%B=),">I("=%)B=9!B=5((?E-(>9,"?%,B[0D
MB`$``$D!QDT!\$V)UDP!P4V)T$G![AM)P>`%30GP28G600'(2(GY2,'O`DC!
MX1Y%B<!("?F)STD)SDTAUD@A^DP)\DR+M"20`0``20'&30'T38G&3`'B38G$
M2<'N&TG!Y`5-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPA
MP4P)\4R+M"28`0``20'&30'U38GF3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,
MB<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+M"2@`0``20'&3`'W
M38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>B?],">)("=%)B=9!
MB=1-(<9,(>E,"?%,B[0DJ`$``$D!QDT!\DF)_DP!T4F)^DG![AM)P>(%30GR
M28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),B[0DL`$`
M`$D!QDT!\$V)UDP!PDV)T$G![AM)P>`%30GP00'02(GZ2,'O`DC!XAY%B<!(
M"?I("=%)B=:)UTTA[DPAT4P)\4R+M"2X`0``20'&30'T38G&3`'A38G$2<'N
M&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4D)SD&)RDTAQDPATDP)
M\DR+M"3``0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,B<))P>@"
M2,'B'D6)[4P)PD@)T4F)T$&)UTTAT$PAX4P)P4R+A"3(`0``20'`3`''38GH
M2`'Y3(GO2<'H&TC!YP5,"<=$C00Y3(GG2<'L`DB)T4C!YQY,">=!B?Q("?E,
M(>E,(>)("<I(BXPDT`$``$@!P4P!T4V)PD@#A"38`0``2`'*3(G!2<'J&TC!
MX05,"=&)R4@!RDR)Z4G![0)(P>$>08G23`GI2`G/28G-08G.3"''32'E20G]
M2HT\.$R)T$R+O"3X`0``3`'O38G52,'@!4G![1M,">B)P$@!QTR)P$G!Z`)(
MP>`>08G]20G`N-;!8LI,,<$QT4B+E"3@`0``2`'"3`'B38GL2`'*3(GI2<'L
M&TC!X05,">%-B=2)R4G!Y!Y(`<I)P>H"20''30GB38G$B=%%B<!-,=1$,>=,
MBZ0DZ`$``$D!Q$T!]$F)SDP!YTF)S$G![AM)P>0%30GT38GN2<'M`DG!YAY%
MB>1-"?5,B[0D\`$``$P!YT&)_$D!QDT!\$V)UDTQ[D0Q\DV)YDD!T$R)XDG!
M[AM(P>(%3`GRB=))`=!(B<I(P>D"2,'B'D6)QD@)RD2)T4V)ZDDQTDP!^4R+
MO"0``@``1#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(
MP>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD$`(``$4QZ$V)U4D!R$R)T4G!
M[1M)`<=(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"0(`@``20'&
M3`'R38GF23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(
MP>(>08G^20G21(GB28G,B<E,`?I-,=1,B[PD(`(``$4QX$V)]$D!T$R)\DG!
M[!M)`<=(P>(%3`GBB=))`=!,B>I)P>T"2,'B'D6)Q$P)ZDR+K"08`@``20'%
M3`'I38G523'51#'O38GE2`'/3(GA2<'M&TC!X05,">F)R4@!STR)\4G![@)(
MP>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD,`(``$4QT$V)ZDD!R$R)Z4G!
MZAM(P>$%3`G1B<E)`<A,B>%(P>$>2<'L`D6)PDD!QTP)X4R+I"0H`@``20'$
M3`'B38GT23',1#'G38G42`'73(G22<'L&TC!X@5,">*)TD@!UTR)ZDG![0)(
MP>(>08G\20G51(GR28G.B<E-,>Y,`?I,B[PD0`(``$4Q\$V)YDD!T$R)XDG!
M[AM(P>(%3`GRB=))`=!,B=))P>H"2,'B'D6)QDP)TDR+E"0X`@``20'"3`'1
M38GJ23'21#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(
MP>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD8`(``$4QZ$V)U4D!R$R)T4G!
M[1M(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"1(`@``20'&3`'R
M38GF18GD23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(
MP>(>08G^20G22(N4)%`"``!(`<))`=1(B<J)R4PQTDD!QT0QPDV)\$D!U$R)
M\DG!Z!M(P>(%3`G"B=))`=1,B>I)P>T"2,'B'D6)X$P)ZDR+K"18`@``20'%
M3`'I38G523'51#'O38G%2`'/3(G!2<'M&TC!X05,">F)R4@!STR)\4G![@)(
MP>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD<`(``$4QXDV)[$P!T4V)ZDG!
M[!M)P>(%30GB38G$18G22<'D'DP!T4G!Z`))`<=-">!,BZ0D:`(``$&)RDD!
MQ$@#A"1X`@``3`'B38GT3`'(33'$1#'G38G42`'73(G22<'L&TC!X@5,">)-
MB>Q)P>T"2<'D'HG230GE18GT38G&2`'733'NB?I-`?Q%B<!$,?%)B=9,`<!-
MB>A,`>%)B=1)P>X;2<'D!4T)]$0!X4V)U$G!Z@))P>0>B<E-">)-,=!$,<=)
MB<A(`?A(B<](P><%2<'H&P'I00':3`G'1`-N($B)3@@!^$R)5AA(B09(B=!(
MP>H"2,'@'DR);B!("=!$`=A(B4802(N$)(@"``!D2"L$)2@```!U$DB!Q)@"
M``!;74%<05U!7D%?P_\5I84```\?1```05=!5D%505154TB#[`A(A?\/A+$`
M``!(BP4JA```3(LP387V#X2>````#[8'28G_28GUA,!T!#P]=55%,>1)BQY(
MA=MT,4UCY$R)]0\?0`!,B>),B?Y(B=__%3&$``"%P'4'0H`\(SUT1DB+70A(
M@\4(2(7;==E(@\0(2(G86UU!7$%=05Y!7\,/'X``````28G\00^V1"0!28/$
M`83`=`0\/77N12G\ZY1F#Q]$``!,*?5*C5PC`4C!_0-!B6T`Z[5F#Q]$```Q
MV^NK#Q]``%-(B?M(@>R@````9$B+!"4H````2(F$))@````QP$B)YO\5P80`
M`(7`=36+5"08@>(`\```@?H`0```=`B!^@"@``!U';X"````2(G?_Q7=A```
MA<`/E,`/ML#K!0\?`#'`2(N4))@```!D2"L4)2@```!U"4B!Q*````!;P_\5
M3(0``&9F+@\?A```````D$%455-,C9PD``#__TB![``0``!(@PPD`$PYW'7O
M2(/L$+H"````,?9D2(L$)2@```!(B80D"``!`#'`B?U(B>/_%3*$``!,C6#_
M3(GB2,'Z/TC!ZC!)C004#[?`2"G022G$>&P/'T``,=),B>:)[_\5`X0``+H(
M``$`2(G>B>__%:."``!(F$B#^`=V,TB-1`/X2#G8<BE(C152A```ZPE(@^@!
M2#G8<A=(BPI(.0AU[T@IV$P!X.L>#Q^``````$F![````0!)@?P``/__=9A(
MQ\#_____2(N4)`@``0!D2"L4)2@```!U#$B!Q!```0!;74%<P_\51(,```\?
M0`!!54%455-(@>RH````9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G[
M=2M(BX0DF````&1(*P0E*`````^%,P$``$B!Q*@```!;74%<05W#9@\?1```
M_Q5*@@``2(G%2(7`=,=(B>__%6&#``!(A<`/A+@```"`>!,N3(U@$W4.08!\
M)`$`=-QF#Q]$``"`>!,N#X2V````2(G?_Q7M@0``3(GG28G%_Q7A@0``08U\
M!0)(8___%7N!``!-B>%)B=B^`0```$F)Q4B)QS'`2,?"_____TB-#08C``#_
M%:2"``!,B>](B>;_%;"!``!,B>^#^/]T$(M$)!@E`/```#T`0```=&C_%4*!
M``!,B>__%7&!``!(B>__%;""``!(A<`/A4____\/'X``````2(GO_Q5'@@``
M2(G?_Q46@0``Z>;^__]F#Q^$``````!!@'PD`2X/A3[___]!@'PD`@`/A/[^
M___I+?___P\?`.B+_O__ZY?_%<.!```/'P#S#Q[Z4TB+'32!``!(C0V=8@``
M2(TU4"(``$B+%2>!``!D2(L[_Q4%@@``3(T%SB,``&1(BSM%,<E(C14`%@``
M3(G!2(TU/"(``%O_)0>!``!F9BX/'X0```````\?0`!!54%455-(@>P`$```
M2(,,)`!(@^P8NO\/``!D2(L$)2@```!(B80D"!```#'`28GD2(G[2(GU2(T]
M_2$``$R)YO\5X8```(7`?A*)P8/H`4ACT(`\%`!U1X7`=3M(BP5\@```2(GJ
M2(G>9$B+./\5#(```$B+A"0($```9$@K!"4H````=4Y(@<08$```6UU!7$%=
MPP\?`(G!9@\?1```3&/IOB\```!,B>=,B>K_%61_``!(A<!TI$B+!2"```!,
MB>E,B>)(B=YD2(LX_Q5-@```ZY__%86````/'T0``$%7059!54%454B)]5-(
MB?M(@^PH9$B+!"4H````2(E$)!@QP#'`@#X]#Y3`2`'%2(GO_Q68?P``2(UT
M)!1(B=])B<0QP.B6^O__2(7`#X0-`0``28G%2(G'_Q5Q?P``3#G@#X/8````
M2&-,)!1,BS6T?@``3(T\S0`````/M@.$P`^$H0$``#P]#X29`0``2(G89@\?
M1```#[90`4B#P`&$TG0%@/H]=>](*=A(F$V++DJ-?"`"_Q6\?@``30']28E%
M`$B%P'1128L&2(U+`4J+%#@/M@.(`CP]="&$P'4,ZQMF#Q]$```\/701#[8!
M2(/"`4B#P0&(`H3`=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$R77O2(M$
M)!AD2"L$)2@````/A0\!``!(@\0H6UU!7$%=05Y!7\,/'T``,<!F#Q]$```/
MME0%`$&(5`4`2(/``832=>[KO0\?0`!,BS7!?0``38L&28,X``^$NP```$R)
MP$4Q[68/'T0``$B#P`A$B>I!@\4!2(,X`'7OC7(#2&/V2,'F`XL%KW\``(7`
M=5M(B?=,B40D",<%F7\```$```#_%;M]``!(B<=(A<`/A%#___])8\U(BW0D
M"$R-/,T`````3(GZ_Q5N?@``28D&2(G'08U%`42);"042)A(QP3'`````.E\
M_O__3(G'_Q7??@``28D&2(G'2(7`#X0!____26/-3(T\S0````#KPP\?`#'`
MZ7_^__^^$````$4Q[>E?_____Q4^?@``9F8N#Q^$```````/'P#S#Q[Z2(L%
MI7T``$B+%:9]``!(C0T'7P``2(TUNAX``&1(BSC_)79^``!F#Q]$``#S#Q[Z
M55-(@>P`$```2(,,)`!(@>P`$```2(,,)`!(@^PH9$B+!"4H````2(F$)!@@
M```QP$B-G"00$```2(GE_Q7B?```2(T-G1X``+H!$```2(G?08G`3(T-AQX`
M`+X!````,<#_%=Q]``"Z`!```$B)[DB)W_\52WT``#')A<!X,(UX`4B)PTAC
M__\59GP``$B)P4B%P'092&/;2(GN2(G'2(G:_Q7<?0``Q@08`$B)P4B+A"08
M(```9$@K!"4H````=0U(@<0H(```2(G(6UW#_Q4G?0``#Q^``````/,/'OKI
M%____Y!F#Q]$``#S#Q[Z05=!5D%505154TB![``0``!(@PPD`$B![+@```!D
M2(L$)2@```!(B80DJ!```#'`28G\2(GS2(T]QQT``$B-="0,Z"7W__^^+P``
M`$R)YTB)Q?\5C'P``$B%P'0_,<!,B>9(C3VD'0``Z![\__],B>!(BY0DJ!``
M`&1(*Q0E*`````^%DP$``$B!Q+@0``!;74%<05U!7D%?PV:02(G?3(TM=!T`
M`$R--5H>``#_%4E\``!,B>Y(B<?_%5U\``!(B<-(A<!TEH`[``^$YP````\?
M0`!(A>UT%$B)WDB)[_\5+WP``(7`#X2J````2(G?_Q5F>P``2(U4`_])B<=(
M.=-R%>LD#Q^``````,8"`$B#Z@%(.=-T!8`Z+W3O2(G?_Q4V>P``28G'3(GG
M_Q4J>P``28U$!P%(/?\/```/AQK___],C;PDH````$R)\4F)V#'`2(/L"+H`
M$```O@$```!,B?]!5$R-#:\<``#_%>%[``!,B?](C70D(/\5ZWH``%I9A<!U
M$(M$)"@E`/```#T`@```=%5,B>XQ__\5>GL``$B)PTB%P`^$K_[__X`[``^%
M'?___TB%[70&@'T`+G0:0;\!````2(T=,QP``.E5____#Q^$``````"`?0$`
M=+7KW@\?A```````O@$```!,B?__%7)[``"%P'693(G^2(T]!1P``.A_^O__
M3(G__Q7F>@``Z5;^____%>MZ``!F9BX/'X0``````/,/'OI3OB\```!(B?O_
M%75Z``!(C5`!2(7`2`]%VDB)WUO_):AZ```/'X0``````/,/'OI54TB![``0
M``!(@PPD`$B#[!AD2(L$)2@```!(B80D"!```#'`2(7_#X3.````@#\`2(G[
M#X3"````_Q6\>0``2(U0`4B!^@`0```/A^,```!(B>5(B>^#^@AR#HG12(G>
MP>D#\TBE2(GS,<GVP@1T"8L+B0^Y!````/;"`G0.1`^W!`MF1(D$#TB#P0*#
MX@%T!P^V%`N(%`](C40%_T@YQ7(5ZQ@/'X``````Q@``2(/H`4@YZ'0%@#@O
M=.^^+P```$B)[_\5B7D``$B%P'0L2#G%<E=(B>__%;YY``!(BY0D"!```&1(
M*Q0E*````'5'2('$&!```%M=PY!(BX0D"!```&1(*P0E*````'4I2('$&!``
M`$B-/84:``!;7?\E=WD```\?@`````#&``#KI`\?`#'`ZZ;_%6YY``!F9BX/
M'X0```````\?`/,/'OI!5T%6055!5%5(C2U>&@``4TB#[!AD2(L$)2@```!(
MB40D"#'`2(U<)`1FD#'`2(G>2(GOZ(/S__](A<!T/DB+!;]W``!(8U0D!$B+
M`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?
M1```2(TM]!D``&8/'X0``````#'`2(G>2(GOZ"/S__](A<!T/DB+!5]W``!(
M8U0D!$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U
M\.NV9@\?1```2(TMG!D``&8/'X0``````#'`2(G>2(GOZ,/R__](A<!T/DB+
M!?]V``!(8U0D!$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(
MB1!(A=)U\.NV9@\?1```2(TM11D``&8/'X0``````#'`2(G>2(GOZ&/R__](
MA<!T/DB+!9]V``!(8U0D!$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0
M$$B#P`A(B1!(A=)U\.NV9@\?1```2(TM[!@``&8/'X0``````#'`2(G>2(GO
MZ`/R__](A<!T/DB+!3]V``!(8U0D!$B+`$B-!-!(BU`(2(D02(72=,\/'X``
M````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```3(TEG!@``&8/'X0``````#'`
M2(G>3(GGZ*/Q__](A<!T/DB+!=]U``!(8U0D!$B+`$B-!-!(BU`(2(D02(72
M=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```3(TE\1<``&8/'X0`
M`````#'`2(G>3(GGZ$/Q__](A<!T/DB+!7]U``!(8U0D!$B+`$B-!-!(BU`(
M2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```3(TUZ!<`
M`&8/'X0``````#'`2(G>3(GWZ./P__](A<!T/DB+!1]U``!(8U0D!$B+`$B-
M!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```
M3(TMDA<``&8/'X0``````#'`2(G>3(GOZ(/P__](A<!T/DB+!;]T``!(8U0D
M!$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV
M9@\?1```3(T]/!<``&8/'X0``````#'`2(G>3(G_Z"/P__](A<!T/DB+!5]T
M``!(8U0D!$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(
MA=)U\.NV9@\?1```3(T]>A8``&8/'X0``````#'`2(G>3(G_Z,/O__](A<!T
M/DB+!?]S``!(8U0D!$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#
MP`A(B1!(A=)U\.NV9@\?1```2(G>2(T]@Q8``.AQ[___2(7`=`U(B<9,B>\Q
MP.A_]/__,<!(B=Y(C3UQ%@``Z$[O__](A<!T$4B)QDB-/6\6```QP.A8]/__
M2(G>2(T]:18``#'`Z"?O__](B<9(A<!T.4R)YS'`Z#7T__](BT0D"&1(*P0E
M*````'5$2(/$&$B)[TB--5,6```QP%M=05Q!74%>05_I!O3__S'`2(G>2(T]
M)18``.C5[O__2(7`=+M(B<9,B?<QP.CC\___ZZS_%5MT``!F9BX/'X0`````
M`/,/'OI(@^P82(T]D!4``&1(BP0E*````$B)1"0(,<!(C70D!.B'[O__2(7`
M=#(/MA"`^C`/E,"$T@^4P@G0@_`!#[;`2(M4)`AD2"L4)2@```!U$$B#Q!C#
M#Q^``````#'`Z^#_%>9S``!F#Q]$``#S#Q[Z2(/L"/\5\G,``(G'_Q7Z<@``
M2(7`=`-(BP!(@\0(PV9F+@\?A```````9I#S#Q[Z055!5$R-)5\5``!52(G]
M3(GG4TB#[!AD2(L$)2@```!(B40D"#'`2(UT)`3HV^W__TB%P'0(@#@`2(G#
M=2Y(BT0D"&1(*P0E*`````^%M````$B)[DB#Q!A,B><QP%M=05Q!7>G#\O__
M#Q\`2(GN2(G'_Q7L<@``2(7`=!](BT0D"&1(*P0E*````'5Y2(/$&%M=05Q!
M7<,/'T``2(GO_Q57<@``2(G?28G%_Q5+<@``28U\!0+_%>AQ``!(@^P(28GH
MO@$```!32,?"_____TB)QTF)Q4R-#=T3``!(C0W#%```,<#_%0AS``!86DB+
M1"0(9$@K!"4H````=0A,B>[I3_____\5H'(``/,/'OI!5TB-%6@4``!(C0T5
M%```059F2`]NPDB-%204``!)B?Y!54B-/6H3``!!5%532('L.`$``&1(BP0E
M*````$B)A"0H`0``2(T%11,``$B-;"042,=$)%``````2,>$)(@`````````
M2(GN2,=$)#``````9D@/;LA(C07W$P``9@]LP69(#V[02(T%[Q,```\I1"1`
M9D@/;L%F2`]NV$B-#=T3``!F#VS"2(T%UQ,```\11"1H9D@/;L)F2`]NX#'`
M9@]LPP\11"1X9D@/;L%F#VS$#RE$)"#H'^S__TB%P'0,@#@`2(G##X6^!```
M_Q7(<0``B<?_%=!P``!(A<`/A`<$``!,BR!-A>0/A/L#``!,B>?_%=)P``!(
MC7P``?\5;W```$4/M@0D28G'2(G#183`=#=,C2U4$P``28/$`44/ML!,B?],
MB>E(Q\+_____O@$````QP$F#QP+_%8)Q``!%#[8$)$6$P'703(UL)&!(C3VT
M$@``ZP]FD$F+?0A)@\4(2(7_=#M(B>XQP.AIZ___28G$2(7`=.&`.`!TW$B)
MQ^@D[/__A<!TT$R)Y_\5UW```$F)QTB%P'4_#Q^``````$R-9"1`38L\)$V%
M_W0J08`_``^$(`,``$R)_^CHZ___A<`/A1`!``!-BWPD"$F#Q`A-A?]UV&:0
M3(G__Q7G;P``2(G?28G$_Q7;;P``18VD!`0$``!-8^1,B>?_%6]O``!338GX
M3(T-?!$``$F)Q4B-!602``"^`0```$C'PO____]02(T-1Q(``$R)[S'`_Q6+
M<```3(GOOL`!``#_%<UP``!?05B#^/]U$_\5#W```$2+"$&#^1$/A?@"``!(
MC80DD````$R)[TB)!"1(B<;_%1IP``")PX7`='Q(BP5%<```28L.38GH2(T5
MF!(``+X!````2(LX,<#_%9AN``!%,>1(BX0D*`$``&1(*P0E*`````^%*P0`
M`$B!Q#@!``!,B>!;74%<05U!7D%?PV8/'X0``````$R)_TF#Q`C_%8-O``!)
MB<=(A<`/A+3^___IXO[__V:0BX0DJ````"4`\```/0!````/A6W___]$B[PD
MK````/\5>V\``$$YQP^%5O___XN$)*@````E_P$``#W``0``#X4_____3(GG
M_Q4J;@``2(GN2(T]\1```$F)Q#'`Z'[I__](A<`/A&4"``!)BSY(B<9GZ/GQ
M__])B<=(A<`/A$T"``!,B?__%41N``!(B<*#^`-^/$B82(E4)`A(C37E$```
M28U\!_S_%=MN``"%P'4?2(M4)`B#^@0/A/$"``"-0OM(F$&`/`<O#X3A`@``
MD$B)[DB-+?4/```QP$B)[^C\Z/__2(7`#X3S`0``#[8`A,`/A.@!```\,`^$
MX`$``$B)[TB--3(0```QP.CO[?__2(TMJ!```$R--8\0``#_%8-M``!52,?"
M_____TV)Z%!,C0U8#P``O@$```!,B>=(C0U9$```,<#_%7EN``!86NM(#Q]$
M``#_%0IN``"#.!%U2_\5/VT``(/#`4B#[`A-B>A53(T-%0\``$R)\;X!````
M4TC'PO____],B>=0,<#_%3%N``!(@\0@OL`!``!,B>?_%6]N``"#^/]TJDR)
M[_\5$6T``$R)YDB-/;<.```QP.@X[?__3(GG9^C_^?__Z=7]__]F+@\?A```
M````13'_Z?C\__\/'X0``````$B+?"0@2(U<)"!(A?]T(I`QP$B)[NC6Y___
M2(7`=`6`.`!U-$B+>PA(@\,(2(7_==^_#0```$R-)2$/``#_%45L``!!N%,`
M``!)B<=(B</IU?O__P\?0`!(B<?_%1]M``!)B<1(A<!TN^F7^___2(L%:VT`
M`$F+#DV)Z$B-%7X/``"^`0```$B+.#'`_Q6^:P``Z2']__]F#Q^$``````!(
MB<=GZ#?Y__](BX0D*`$``&1(*P0E*`````^%/0$``$B!Q#@!``!(B=];74%<
M05U!7D%?_R6F;```9@\?1```38L^Z:O]__\/'X0``````#'V3(G_,<#_%4-L
M``!!B<:%P`^$"/[__XG'Z$'H__])B<=(A<`/B/7]__\QTDB-</9$B??_%9YL
M``!(C70D&KH&````1(GW_Q4[:P``@7PD&@!#04,/A<7]__]F@7PD'DA%#X6X
M_?__28UWSC'21(GW_Q5A;```2(L<)+HH````1(GW2(G>_Q7\:@``O@$```!-
MB>A,B>=(C05"#@``QH0DN`````!(C0T$#@``2,?"_____U!,C0WT#```,<!3
M_Q4C;```65[I`O[__P\?0`!-BW8(387V#X03_?__3(GW_Q4*:P``2(/X`P^&
M`/W__TF-?`;\2(TUL`T``/\5IFL``(7`30]$_NGC_/___Q6-:P``9F8N#Q^$
M``````!FD/,/'OI!5$B-/:8,``!54TB#[!!(BQWF:@``9$B+!"4H````2(E$
M)`@QP$R-9"0$3(GF9$B+*P^VA;````"(A;$````QP.B6Y?__2(7`=`F`.#$/
MA(@!```QP&?HP/'__V1(BRM(B>^Y`P```+H!````2(TU1PT``/\5"FH``$B)
MQ4B%P'0I2(M`$&1(BSM(C14L#0``2(LP_Q4":@``2(M%$$B+,/9&#D`/A6$!
M``!D2(L[N0,```"Z`0```$B--0(-``#_%;YI``!(B<5(A<!T+DR)YDB-/:4+
M```QP.C]Y/__2(G"2(7`#X0!`0``2(M%$&1(BSM(BS#_%:!I``!D2(L[N@$`
M``!(C36X#```_Q4*:0``9$B+.TB-%;P,``!(B<;_%79I``!D2(L#3(GF2(T]
M0`L``,:`L0`````QP.B:Y/__2(D%$VL``$B)PTB%P'1#OL`!``!(B=__%;5J
M``"-4`&#^@%V"8/X$0^%JP```$B+1"0(9$@K!"4H````#X7%````2(/$$%M=
M05S##Q^``````$B+/<EJ``!GZ#OW__](B06T:@``2(G#2(7`=:%(BT0D"&1(
M*P0E*`````^%A0```$B-/;D,```QP/\5T6D``&8/'X0``````(!X`0`/A'K^
M___I:?[__Y!(BP5Q:@``2(LP2(M%$$B+..@:Z/__Z?7^__\/'T0``&1(BSO_
M%5YI``#ID/[__TB+5"0(9$@K%"4H````=1Z)P4B+!3!J``!(B=I(C3UN#```
M2(LP,<#_%5MI``#_%2UI``!F9BX/'X0``````&:0\P\>^E5(B?U32(/L&&1(
MBP0E*````$B)1"0(,<!GZ$WN__^^+P```$B)PTB)Q_\5E&@``$B%P$B-4`%(
M#T7:2(G?_Q7(:```2(UT)`1(C3T;"@``2(G#,<#H(N/__TB%P'0=#[80A-(/
ME,"`^C`/E,((T'4+2(7M=`:`?0``=2!(BT0D"&1(*P0E*````'5'2(/$&%M=
MPV8/'X0``````+H$````2(TU=@H``$B)W_\56V<``(7`=<=(BT0D"&1(*P0E
M*````'4.2(/$&$B)[UM=Z0GE____%4-H```/'P#S#Q[Z2(/L"+^`````_Q4E
M9P``9@]O!35)``!(QT`P``````\1`&8/;P4R20``QT!X``````\10!!F#V\%
M+TD```\10"!(@\0(PV8/'T0``/,/'OI!5TACPD%628G&055!5$F)_%5(C6\X
M4TB)\TB#[`A(BW<H2(M7,(T,QD@Y\4B)3RA(@](`2,'H'4@!T$B)1S!(8T=X
MA<`/A>D```!!@_X_#XXO`0``08/N0$6)]T'![P9%C6\!2<'E!DD!W9#S#V\#
M3(GG2(/#0`\110#S#V]+T`\131#S#V]3X`\152#S#V];\`\173#H0<O__TPY
MZW7,0<'G!D4I_DECQDB#^`AR7$F+50!)C4PD0$B#X?A)B50D.$F+5`7X2(E4
M!?A(*<U(`>A)*>U(@^#X2(/X"'(82(/@^#'228MT%0!(B3012(/""$@YPG+N
M18ET)'A(@\0(6UU!7$%=05Y!7\.0J`1U?$B%P'3B00^V50!!B%0D.*@"=-1!
M#[=4!?YFB50%_NO'#Q]``$&_0````$B-?`4`2(G>02G'13GW10]/_DUC[TR)
MZO\5'&<``$&+1"1X1`'X08E$)'B#^$!UDDR)YT4I_DP!Z^ADRO__Z<[^__\/
M'X``````28G=Z1O___]!BU4`08E4)#A!BU0%_(E4!?SI5/___V8/'X0`````
M`/,/'OI!5DR-=CA!54%454B)_5-,BVXH2(GS3(MF,$R)Z$C!Z`.#X#^-4`'&
M1`8X@$ACRH/Z.`^.A`$``+Y`````3`'Q*=9T#S'`B<*#P`'&!!$`.?!R\TB)
MW^C1R?__9@_OP`\10SA)QT8P`````$$/$48000\11B!,B>)!#[;%3(GO3(GN
M2,'J&$C!X`A,B>%(P>\028G03(GJ2,'N&`^VUD`/MO]`#[;V2,'I$$@)T$R)
MX@^VR4C!X`A("?@/MOY!#[;02,'@"$@)\$$/MO1(P>`(2`GP2,'@"$@)^$B)
MWTC!X`A("<A(P>`(2`G02(E#<.@XR?__2(L#2(G?2,'H&(A%`$B+`TC!Z!"(
M10%(BP.(90)(BP.(10-(BT,(2,'H&(A%!$B+0PA(P>@0B$4%2(M#"(AE!DB+
M0PB(10=(BT,02,'H&(A%"$B+0Q!(P>@0B$4)2(M#$(AE"DB+0Q"(10M(BT,8
M2,'H&(A%#$B+0QA(P>@0B$4-2(M#&(AE#DB+0QB(10](BT,@2,'H&(A%$$B+
M0R!(P>@0B$412(M#((AE$DB+0R"(11-;74%<05U!7O\ESV,```\?@`````"X
M.````$D!SC'_*="#^`AR1TF-3@B)PDG'!@````!)QT06^`````!(@^'X22G.
M1`'P@^#X@_@(#X)\_O__@^#X,=*)UH/""$B)/#$YPG+SZ67^__\/'T``J`1U
M)(7`#X15_O__0<8&`*@"#X1)_O__,=)F08E4!O[I//[__P\?`$''!@````!!
MQT0&_`````#I)/[__V8N#Q^$``````"0\P\>^DB+#7UD``#_):]B``````#S
M#Q[Z2(/L"$B#Q`C#````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R]S96QF+V5X90`O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"4P,G@`)7,E<R5S)7,`
M<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].
M`#$N,#4X`"UE`"TM```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O
M9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-
M04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@
M(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!
M1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY
M("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D
M8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M
M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I
M<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I
M('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I
M.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T
M;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T
M;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA
M;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N
M86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D
M<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R
M;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E
M<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD
M7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!0
M05(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!
M0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2![
M"F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]
M"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&
M2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A
M8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,
M17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C
M=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@
M)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE
M(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,
M12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L
M"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U
M8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD
M;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E
M7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF
M;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F
M24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F
M:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M
M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E
M96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD
M:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B
M.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+
M6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@
M<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@
M(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A
M73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A
M7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I
M92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q
M("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O
M=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@
M>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*
M?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\
M9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E
M;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E
M<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS
M<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@
M/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL
M"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D
M(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II
M<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@
M;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R
M:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?
M;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D
M9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#([
M"B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#
M04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!
M1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I
M;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@
M24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A
M9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L
M("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S
M*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C
M:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M
M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^
M9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_
M<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK
M*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@
M/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C
M=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE
M;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?
M;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T
M;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?
M9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F
M:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D
M("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE
M+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]
M?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO
M<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E
M;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D
M<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T
M96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D
M9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S
M>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!#04-(10``
M<&5R;'AS:2YC`````````/____\`````_____P`````!(T5G`````(FKS>\`
M````_MRZF`````!V5#(0`````/#ATL,````````````````!&P,[Y````!L`
M``"`?___#`8``+"!__\``0``L(+__Q@!```@F?__:`$``/"9__^T`0``@)K_
M_]@!``"`F___&`(```"=__]4`@``8)W__W`"``!`GO__L`(``)"@___\`@``
MP*#__Q`#``"@H?__1`,``+"A__]8`P``X*/__[P#```0I/__V`,``&"E__\4
M!```<*K__V`$``#@JO__?`0``!"K__^4!```(*S___`$``!`L___H`4``*"U
M___4!0``@+;__S@&``#0MO__4`8``("X__^<!@``X+K__^`&````````%```
M```````!>E(``7@0`1L,!PB0`0``%````!P```"H@/__)@````!$!Q``````
M3````#0```"0@?__:Q8```!"#A"/`DD.&(X#0@X@C01"#BB,!4$.,(8&00XX
M@P='#M`%`T(6"@XX00XP00XH0@X@0@X80@X00@X(00L```!(````A````+"7
M___,`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)M"@XX
M1`XP00XH0@X@0@X80@X00@X(2`L`(````-`````TF/__A`````!!#A"#`DH.
ML`$"<0H.$$$."$$+/````/0```"@F/___`````!"#A",`D$.&(8#00X@@P1(
M#`N@@`11#0=$#K"`!`+0"@X@00X800X00@X(00L``#@````T`0``8)G__WT!
M````0@X0C0)"#AB,`T$.((8$00XH@P5'#M`!?@H.*$$.($$.&$(.$$(."$<+
M`!@```!P`0``I)K__U$`````10X0@P("1@X(```\````C`$``.B:___;````
M`$(.$(T"0@X8C`-!#B"&!$$.*(,%1PZH($D.P"`">`H.*$$.($$.&$(.$$(.
M"$0+2````,P!``"(F___0@(```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&
M1`XX@P='#F`#'0$*#CA!#C!!#BA"#B!"#AA"#A!"#@A%"Q`````8`@``C)W_
M_RH`````````,````"P"``"HG?__V0````!%#A"&`D$.&(,#1PZ8($P.F$!)
M#L!``JL*#AA$#A!!#@A!"Q````!@`@``5)[__PH`````````8````'0"``!0
MGO__)0(```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#K@@3`[P
M(0)R"@XX00XP00XH0@X@0@X80@X00@X(0PL"NP[X(4\.@")<#O@A00[P(0``
M`!@```#8`@``'*#__R@`````10X0@P)=#@@````X````]`(``#"@__]"`0``
M`$4.$(8"00X8@P-'#I@@20ZP(`+F"@X800X000X(0@M:"@X82`X000X(30M(
M````,`,``$2A__\%!0```$8.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9(#CB#
M!T0.4`.F!`H..$T.,$$.*$(.($(.&$(.$$(."$4+&````'P#```(IO__:@``
M``!(#B`"4`H."$@+`!0```"8`P``7*;__R,`````2`X06@X(`%@```"P`P``
M=*;__Q`!````1@X0C0)"#AB,`T@.((8$1PXH@P5$#D`"0@H.*$8.($$.&$(.
M$$(."$@+90H.*$$.($$.&$(.$$(."$4+9`Y(20Y09`Y(00Y`````K`````P$
M```HI___$P<```!&#A"/`E`.&(X#40X@C01)#BB,!4$.,(8&00XX@P='#O`"
M`_$!#O@"80Z``V$.^`)"#O`"`GL*#CA$#C!!#BA"#B!"#AA"#A!"#@A*"P-&
M`0[X`DL.@`-?#O@"00[P`E\.^`)$#H`#4`Z(`TL.D`-,#O`"`QP!"@XX1`XP
M00XH0@X@0@X80@X00@X(3`L"Q0[X`DH.@`-'#O@"00[P`@`P````O`0``)BM
M__]3`@```$8.$(P"2`X8A@-!#B"#!$0.,`-Y`0H.($$.&$$.$$(."$@+-```
M`/`$``#$K___W0````!%#A"&`D0.&(,#1`XP`H<*#AA!#A!!#@A*"VT*#AA$
M#A!!#@A%"P`H````*`4``&QY__\B`@```$4.$(8"00X8@P-$#E`#=P$*#AA#
M#A!!#@A!"Q0```!4!0``0+#__TH`````2`X0`D$."$@```!L!0``>+#__Z<!
M````1@X0CP)%#AB.`T4.((T$0@XHC`5$#C"&!D4..(,'1PY``N(*#CA!#C!!
M#BA"#B!"#AA"#A!"#@A""P!`````N`4``-RQ__]5`@```$8.$(X"1@X8C0-"
M#B",!$$.*(8%1`XP@P8#F0$*#BA!#B!"#AA"#A!"#@A-"P```````!````#\
M!0``^+/__Q$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$`C````````\"(````````!````````
M`,T"`````````0````````#8`@```````!T`````````600````````,````
M```````@````````#0````````"46P```````!D``````````+P````````;
M``````````@`````````&@`````````(O````````!P`````````"```````
M``#U_O]O`````-`#````````!0````````"P#0````````8`````````$`4`
M```````*`````````'P$````````"P`````````8`````````!4`````````
M```````````'`````````&@3````````"`````````!X!@````````D`````
M````&``````````>``````````@`````````^___;P`````!```(`````/[_
M_V\`````Z!(```````#___]O``````$`````````\/__;P`````L$@``````
M`/G__V\`````!```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````!"\````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````"E!!4BYP;0H``````````-AB
M````````1T-#.B`H1TY5*2`Q,RXQ+C$@,C`R,S`T,CD``"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG;G4N8G5I;&0M:60`
M+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N
M=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+FEN:70`+G1E>'0`
M+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A
M<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O
M;6UE;G0`````````````````````````````````````````````````````
M````````````````````````````````````"P````$````"`````````!@#
M````````&`,````````<`````````````````````0``````````````````
M`!,````'`````@`````````X`P```````#@#````````4```````````````
M``````@````````````````````F````!P````(`````````B`,```````"(
M`P```````"0````````````````````$````````````````````.0````<`
M```"`````````*P#````````K`,````````@````````````````````!```
M`````````````````$<```#V__]O`@````````#0`P```````-`#````````
M0`$````````&``````````@```````````````````!1````"P````(`````
M````$`4````````0!0```````*`(````````!P````$````(`````````!@`
M````````60````,````"`````````+`-````````L`T```````!\!```````
M`````````````0```````````````````&$```#___]O`@`````````L$@``
M`````"P2````````N``````````&``````````(``````````@````````!N
M````_O__;P(`````````Z!(```````#H$@```````(``````````!P````$`
M```(````````````````````?0````0````"`````````&@3````````:!,`
M``````!X!@````````8`````````"``````````8`````````(<````!````
M!@``````````(``````````@````````&P````````````````````0`````
M``````````````"-`````0````8`````````("`````````@(````````'$[
M```````````````````0````````````````````DP````$````&````````
M`)1;````````E%L````````-````````````````````!```````````````
M`````)D````!`````@``````````8`````````!@````````H$``````````
M`````````!````````````````````"A`````0````(`````````H*``````
M``"@H````````.0````````````````````$````````````````````KP``
M``$````"`````````(BA````````B*$````````0!@``````````````````
M"````````````````````+D````.`````P``````````O`````````"L````
M````"`````````````````````@`````````"`````````#%````#P````,`
M````````"+P````````(K`````````@````````````````````(````````
M``@`````````T0````8````#`````````!"\````````$*P```````#0`0``
M``````<`````````"``````````0`````````-H````!`````P````````#@
MO0```````."M````````(`(```````````````````@`````````"```````
M``#?`````0````,``````````,``````````L````````"@`````````````
M```````(````````````````````Y0````@````#`````````"C`````````
M*+`````````H````````````````````"````````````````````.H````!
M````,````````````````````"BP````````&P````````````````````$`
M`````````0`````````!`````P````````````````````````!#L```````
A`/,````````````````````!````````````````````
